@@ -1,5 +1,6 @@
 test_that("AuthenticationManager isAuthValid() for v2 node works", {
   skip_on_cran()
+  skip_if_down()
   library(dataone)
   am <- AuthenticationManager()
   expect_false(is.null(am))
@@ -18,6 +19,7 @@ test_that("AuthenticationManager isAuthValid() for v2 node works", {
 
 test_that("AuthenticationManager getAuthMethod(), getToken(), getCert() work", {
   skip_on_cran()
+  skip_if_down()
   am <- AuthenticationManager()
   expect_false(is.null(cm))
   expect_false(is.null(am))
@@ -39,6 +41,7 @@ test_that("AuthenticationManager getAuthMethod(), getToken(), getCert() work", {
 
 test_that("getAuthExpires() works", {
   skip_on_cran()
+  skip_if_down()
   am <- AuthenticationManager()
   expect_false(is.null(cm))
   expect_false(is.null(am))
@@ -61,20 +64,19 @@ test_that("getAuthExpires() works", {
 
 test_that("isCertExpired() works", {
   skip_on_cran()
+  skip_if_down()
   am <- AuthenticationManager()
   cn <- CNode("STAGING")
   # Suppress openssl, cert missing warnings
-  suppressMessages(authValid <- dataone:::isAuthValid(am, cn))
+  authValid <- dataone:::isAuthValid(am, cn)
   if(authValid) {
     expDate <- dataone:::getAuthExpires(am, cn)
-    # TODO: check token exp date when JWT available.
-    #ct <- format(Sys.time(), format="%F %H:%M:%S GMT", tz="UTC")
-    ct <- as.POSIXct(Sys.time(), tz="GMT") 
+    ct <- as.POSIXct(Sys.time(), tz=format(expDate, "%Z"))
     if(!is.na(expDate) && !is.null(expDate)) {
       if(dataone:::isAuthExpired(am, cn)) {
         expect_true(expDate > ct) 
       } else {
-        expect_false(expDate < ct) 
+        expect_false(expDate < ct)
       }
     }
   }
@@ -82,6 +84,7 @@ test_that("isCertExpired() works", {
 
 test_that("getAuthSubject() works", {
   skip_on_cran()
+  skip_if_down()
   am <- AuthenticationManager()
   cn <- CNode("STAGING")
   # Suppress openssl, cert missing warnings
@@ -98,6 +101,7 @@ test_that("getAuthSubject() works", {
 
 test_that("obscureAuth(), restoreAuth() work", {
   skip_on_cran()
+  skip_if_down()
   am <- AuthenticationManager()
   cn <- CNode("STAGING")
   # Disable authentication
